irl\_benchmark.irl.collect package
==================================

Module contents
---------------

.. automodule:: irl_benchmark.irl.collect
    :members:
    :undoc-members:
    :show-inheritance:
